; docformat = 'rst'
;+
; This is an example program to demontrate how to create a multiple image plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "multiple_image_plot" and run it like this::
;       IDL> .RUN multiple_image_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Multiple_Image_Plot
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   head = Reverse(cgDemoData(8), 2)
   s = Size(head, /Dimensions)
   
   ; Load color table to use for images.
   cgLoadCT, 0
   
   ; Set up the display window.
   cgDisplay, 9*s[0], 6*s[1]
   !P.Multi = [0, 9, 6]
   !X.OMargin = [0, 25]
   !Y.OMargin = [0, 8]
   
   ; Draw the images.
   FOR j=0,53 DO cgImage, head[*,*,j], Background='white', MultiMargin = 0.25
   
   ; Clear the multiple plot variable.
   !P.Multi = 0
   
   ; Draw the color bar for the images.
   cgColorbar, /Vertical, Range=[0,10], Format='(F0.2)', $
       Position=[0.94, 0.15, 0.97, 0.80]
       
   ; Add a title to the plot.
   cgText, 0.45, 0.95, 'MRI Study of the Head', /Normal, Alignment=0.5
   
   ; Clean up.
   !X.OMargin=0 & !Y.OMargin=0      
       
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Multiple_Image_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Multiple_Image_Plot', WTitle='Multiple Image Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'multiple_image_plot.ps'
  Multiple_Image_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'multiple_image_plot.ps', /PNG, Width=600

END